@@ -1,5 +1,6 @@
 from typing import List
 
+from .options import PolytopeOptions
 from .shapes import ConvexPolytope
 from .utility.exceptions import AxisOverdefinedError
 
@@ -37,17 +38,18 @@ class Request:
 
 
 class Polytope:
-    def __init__(self, datacube, engine=None, axis_options=None, datacube_options=None):
+    def __init__(self, datacube, engine=None, options=None):
         from .datacube import Datacube
         from .engine import Engine
 
-        if axis_options is None:
-            axis_options = {}
-        if datacube_options is None:
-            datacube_options = {}
+        if options is None:
+            options = {}
 
-        self.datacube = Datacube.create(datacube, axis_options)
+        axis_options, compressed_axes_options, config, alternative_axes = PolytopeOptions.get_polytope_options(options)
+
+        self.datacube = Datacube.create(datacube, config, axis_options, compressed_axes_options, alternative_axes)
         self.engine = engine if engine is not None else Engine.default()
+        self.time = 0
 
     def slice(self, polytopes: List[ConvexPolytope]):
         """Low-level API which takes a polytope geometry object and uses it to slice the datacube"""
@@ -55,6 +57,7 @@ class Polytope:
 
     def retrieve(self, request: Request, method="standard"):
         """Higher-level API which takes a request and uses it to slice the datacube"""
+        self.datacube.check_branching_axes(request)
         request_tree = self.engine.extract(self.datacube, request.polytopes())
         self.datacube.get(request_tree)
         return request_tree
