@@ -8,9 +8,14 @@ from .exceptions import AxisNotFoundError, AxisOverdefinedError, AxisUnderdefine
 
 def group(polytopes: List[ConvexPolytope]):
     # Group polytopes into polytopes which share the same axes
+    # If the polytopes are orthogonal and not in a union, we first group them together into an additional list
+    # so we can treat them together as a single object
     groups = {}
     for p in polytopes:
-        groups.setdefault(tuple(sorted(p.axes())), []).append(p)
+        if p.is_orthogonal and not p.is_in_union:
+            groups.setdefault(tuple(sorted(p.axes())), [[]])[0].append(p)
+        else:
+            groups.setdefault(tuple(sorted(p.axes())), []).append(p)
     concatenation = []
     for other_group in list(groups.keys()):
         for key in other_group:
